==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/PivotDataField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class PivotDataField (  SpireObject, IPivotDataField, ICloneParent) :
    """

    """
    @property

    def Name(self)->str:
        """

        """
        GetDllLibXls().PivotDataField_get_Name.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_Name.restype=c_void_p
        ret = PtrToStr(GetDllLibXls().PivotDataField_get_Name(self.Ptr))
        return ret


    @property

    def Subtotal(self)->'SubtotalTypes':
        """

        """
        GetDllLibXls().PivotDataField_get_Subtotal.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_Subtotal.restype=c_int
        ret = GetDllLibXls().PivotDataField_get_Subtotal(self.Ptr)
        objwraped = SubtotalTypes(ret)
        return objwraped

    @Subtotal.setter
    def Subtotal(self, value:'SubtotalTypes'):
        GetDllLibXls().PivotDataField_set_Subtotal.argtypes=[c_void_p, c_int]
        GetDllLibXls().PivotDataField_set_Subtotal(self.Ptr, value.value)

    @property
    def BaseItem(self)->int:
        """

        """
        GetDllLibXls().PivotDataField_get_BaseItem.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_BaseItem.restype=c_int
        ret = GetDllLibXls().PivotDataField_get_BaseItem(self.Ptr)
        return ret

    @BaseItem.setter
    def BaseItem(self, value:int):
        GetDllLibXls().PivotDataField_set_BaseItem.argtypes=[c_void_p, c_int]
        GetDllLibXls().PivotDataField_set_BaseItem(self.Ptr, value)

    @property
    def BaseField(self)->int:
        """

        """
        GetDllLibXls().PivotDataField_get_BaseField.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_BaseField.restype=c_int
        ret = GetDllLibXls().PivotDataField_get_BaseField(self.Ptr)
        return ret

    @BaseField.setter
    def BaseField(self, value:int):
        GetDllLibXls().PivotDataField_set_BaseField.argtypes=[c_void_p, c_int]
        GetDllLibXls().PivotDataField_set_BaseField(self.Ptr, value)

    @property

    def ShowDataAs(self)->'PivotFieldFormatType':
        """

        """
        GetDllLibXls().PivotDataField_get_ShowDataAs.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_ShowDataAs.restype=c_int
        ret = GetDllLibXls().PivotDataField_get_ShowDataAs(self.Ptr)
        objwraped = PivotFieldFormatType(ret)
        return objwraped

    @ShowDataAs.setter
    def ShowDataAs(self, value:'PivotFieldFormatType'):
        GetDllLibXls().PivotDataField_set_ShowDataAs.argtypes=[c_void_p, c_int]
        GetDllLibXls().PivotDataField_set_ShowDataAs(self.Ptr, value.value)


    def Clone(self ,parent:'SpireObject')->'SpireObject':
        """

        """
        intPtrparent:c_void_p = parent.Ptr

        GetDllLibXls().PivotDataField_Clone.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PivotDataField_Clone.restype=c_void_p
        intPtr = GetDllLibXls().PivotDataField_Clone(self.Ptr, intPtrparent)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/PivotDataField.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class PivotDataField (  SpireObject, IPivotDataField, ICloneParent) :
    """

    """
    @property

    def Name(self)->str:
        """

        """
        GetDllLibXls().PivotDataField_get_Name.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_Name.restype=c_void_p
        ret = PtrToStr(CallCFunction(GetDllLibXls().PivotDataField_get_Name, self.Ptr))
        return ret


    @property

    def Subtotal(self)->'SubtotalTypes':
        """

        """
        GetDllLibXls().PivotDataField_get_Subtotal.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_Subtotal.restype=c_int
        ret = CallCFunction(GetDllLibXls().PivotDataField_get_Subtotal, self.Ptr)
        objwraped = SubtotalTypes(ret)
        return objwraped

    @Subtotal.setter
    def Subtotal(self, value:'SubtotalTypes'):
        GetDllLibXls().PivotDataField_set_Subtotal.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().PivotDataField_set_Subtotal, self.Ptr, value.value)

    @property
    def BaseItem(self)->int:
        """

        """
        GetDllLibXls().PivotDataField_get_BaseItem.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_BaseItem.restype=c_int
        ret = CallCFunction(GetDllLibXls().PivotDataField_get_BaseItem, self.Ptr)
        return ret

    @BaseItem.setter
    def BaseItem(self, value:int):
        GetDllLibXls().PivotDataField_set_BaseItem.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().PivotDataField_set_BaseItem, self.Ptr, value)

    @property
    def BaseField(self)->int:
        """

        """
        GetDllLibXls().PivotDataField_get_BaseField.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_BaseField.restype=c_int
        ret = CallCFunction(GetDllLibXls().PivotDataField_get_BaseField, self.Ptr)
        return ret

    @BaseField.setter
    def BaseField(self, value:int):
        GetDllLibXls().PivotDataField_set_BaseField.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().PivotDataField_set_BaseField, self.Ptr, value)

    @property

    def ShowDataAs(self)->'PivotFieldFormatType':
        """

        """
        GetDllLibXls().PivotDataField_get_ShowDataAs.argtypes=[c_void_p]
        GetDllLibXls().PivotDataField_get_ShowDataAs.restype=c_int
        ret = CallCFunction(GetDllLibXls().PivotDataField_get_ShowDataAs, self.Ptr)
        objwraped = PivotFieldFormatType(ret)
        return objwraped

    @ShowDataAs.setter
    def ShowDataAs(self, value:'PivotFieldFormatType'):
        GetDllLibXls().PivotDataField_set_ShowDataAs.argtypes=[c_void_p, c_int]
        CallCFunction(GetDllLibXls().PivotDataField_set_ShowDataAs, self.Ptr, value.value)


    def Clone(self ,parent:'SpireObject')->'SpireObject':
        """

        """
        intPtrparent:c_void_p = parent.Ptr

        GetDllLibXls().PivotDataField_Clone.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().PivotDataField_Clone.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().PivotDataField_Clone, self.Ptr, intPtrparent)
        ret = None if intPtr==None else SpireObject(intPtr)
        return ret
